@@ -5,7 +5,7 @@ from basxbread.layout import ObjectFieldValue
 from basxbread.layout.components.datatable import DataTableColumn
 from basxbread.layout.components.icon import Icon
 from basxbread.layout.components.modal import modal_with_trigger
-from basxbread.utils import Link, ModelHref, reverse_model
+from basxbread.utils import ModelHref, reverse_model
 from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 from htmlgenerator import mark_safe
@@ -63,15 +63,19 @@ def tile_with_datatable(model, queryset, columns, request):
             columns=columns,
             rowactions=[
                 editmodal(),
-                Link(
+                layout.button.Button(
+                    _("Delete"),
+                    icon="trash-can",
+                    notext=True,
+                    small=True,
+                    buttontype="ghost",
+                ).as_submit(
                     href=ModelHref(
                         model,
                         "delete",
                         kwargs={"pk": hg.C("row.pk")},
                         query={"next": request.get_full_path()},
                     ),
-                    iconname="trash-can",
-                    label=_("Delete"),
                 ),
             ],
             primary_button=layout.button.Button(
