@@ -1,22 +1,23 @@
-import bread
+import basxbread
 import htmlgenerator as hg
-from bread import layout
-from bread.layout.components import tag
-from bread.layout.components.icon import Icon
-from bread.utils import ModelHref
+from basxbread import layout
+from basxbread.layout.components import tag
+from basxbread.layout.components.icon import Icon
+from basxbread.utils import ModelHref
 from django.conf import settings
 from django.shortcuts import get_object_or_404
 from django.utils.formats import localize
 from django.utils.timezone import localtime
 from django.utils.translation import gettext_lazy as _
+from dynamic_preferences.registries import global_preferences_registry
 
 from basxconnect.core import models
 from basxconnect.core.layouts.editperson.common.utils import tile_with_icon
 from basxconnect.core.models import Person
 from basxconnect.mailer_integration.models import Interest, Subscription
 
-R = bread.layout.grid.Row
-C = bread.layout.grid.Col
+R = basxbread.layout.grid.Row
+C = basxbread.layout.grid.Col
 
 
 def mailer_integration_tile(request):
@@ -167,12 +168,26 @@ def modal_edit_subscription(mailingpreferences):
 
 
 def modal_add_subscription(email: models.Email):
+    preferred_language = email.person.preferred_language
+    set_language = (
+        global_preferences_registry.manager()["mailchimp__synchronize_language"]
+        and preferred_language
+    )
+    disable_interests = global_preferences_registry.manager()[
+        "mailchimp__disable_interests"
+    ]
     ret = layout.modal.Modal.with_ajax_content(
         heading=_("Add subscription"),
         url=ModelHref(
             Subscription,
             "ajax_add",
-            query={"asajax": True, "email": email.pk, "status": "subscribed"},
+            query={
+                "asajax": True,
+                "email": email.pk,
+                "status": "subscribed",
+                **({"language": preferred_language} if set_language else {}),
+                **({"interests": ""} if disable_interests else {}),
+            },
         ),
         submitlabel=_("Save"),
     )
